@@ -1,38 +1,66 @@
 ;;; leim-list.el -- list of LEIM (Library of Emacs Input Method)
 ;;
 ;; This file contains a list of LEIM (Library of Emacs Input Method)
-;; in the same directory as this file.  Loading this file registers
-;; the whole input methods in Emacs.
+;; methods in the same directory as this file.  Loading this file
+;; registers all the input methods in Emacs.
 ;;
 ;; Each entry has the form:
 ;;   (register-input-method
 ;;    INPUT-METHOD LANGUAGE-NAME ACTIVATE-FUNC
 ;;    TITLE DESCRIPTION
 ;;    ARG ...)
-;; See the function `register-input-method' for the meanings of arguments.
+;; See the function `register-input-method' for the meanings of the arguments.
 ;;
 ;; If this directory is included in load-path, Emacs automatically
 ;; loads this file at startup time.
 
+(register-input-method
+ "chinese-ctlaub" "Chinese-BIG5" 'quail-use-package
+ "$(0N,Gn(B" "$(0KH)tTT&,!(N,Tg>A*#Gn5x!((B"
+ "quail/CTLau-b5")
+(register-input-method
+ "chinese-ctlau" "Chinese-CNS" 'quail-use-package
+ "$AAuTA(B" "$A::WVJdHk!KAuN}OiJ=TARt!K(B"
+ "quail/CTLau")
+(register-input-method
+ "chinese-b5-quick" "Chinese-BIG5" 'quail-use-package
+ "$(0X|(BB" "$(0&d'GTT&,!JX|/y!K(BBIG5"
+ "quail/quick-b5")
+(register-input-method
+ "chinese-b5-tsangchi" "Chinese-BIG5" 'quail-use-package
+ "$(06A(BB" "$(0&d'GTT&,!J6AQo!K(BBIG5"
+ "quail/tsang-b5")
+(register-input-method
+ "chinese-cns-quick" "Chinese-CNS" 'quail-use-package
+ "$(Gv|(BC" "$(GDcEFrSD+!Jv|Mx!K(BCNS"
+ "quail/quick-cns")
+(register-input-method
+ "chinese-cns-tsangchi" "Chinese-CNS" 'quail-use-package
+ "$(GT?(BC" "$(GDcEFrSD+!JT?on!K(BCNS"
+ "quail/tsang-cns")
+(register-input-method
+ "chinese-py" "Chinese-CNS" 'quail-use-package
+ "$AF4(BG" "$A::WVJdHk!KF4Rt!K(B"
+ "quail/PY")
+(register-input-method
+ "chinese-ziranma" "Chinese-CNS" 'quail-use-package
+ "$AWTH;(B" "$A::WVJdHk!K!>WTH;!?!K(B"
+ "quail/ZIRANMA")
 (register-input-method
  "chinese-zozy" "Chinese-BIG5" 'quail-use-package
  "$(0I\0D(B" "$(0&d'GTT&,!JI\@c0D5x!K(B"
  "quail/ZOZY")
-(register-input-method
- "chinese-ziranma" "Chinese-GB" 'quail-use-package
- "$AK+F4(B" "$A::WVJdHk!KWTH;K+F4!K(B "
- "quail/ZIRANMA")
 (register-input-method
  "chinese-tonepy" "Chinese-GB" 'quail-use-package
- "$A5wF4(B" "$A::WVJdHk!K4x5wF4Rt!K# (B"
+ "$A5wF4(B" "$A::WVJdHk!K4x5wF4Rt!K(B"
  "quail/TONEPY")
 (register-input-method
  "chinese-sw" "Chinese-GB" 'quail-use-package
- "$AJWN2(B" "$A::WVJdHk!KJWN2!K# (B"
+ "$AJWN2(B" "$A::WVJdHk!KJWN2!K(B"
  "quail/SW")
 (register-input-method
  "chinese-qj" "Chinese-GB" 'quail-use-package
- "$AH+(BG" "$A::WVJdHk!KH+=G!K# (B"
+ "$AH+(BG" "$A::WVJdHk!KH+=G!K(B"
  "quail/QJ")
 (register-input-method
  "chinese-qj-b5" "Chinese-BIG5" 'quail-use-package
@@ -40,16 +68,12 @@
  "quail/QJ-b5")
 (register-input-method
  "chinese-punct" "Chinese-GB" 'quail-use-package
- "$A1j(BG" "$A::WVJdHk!K1j5c7{:E!K# (B"
+ "$A1j(BG" "$A::WVJdHk!K1j5c7{:E!K(B"
  "quail/Punct")
 (register-input-method
  "chinese-punct-b5" "Chinese-BIG5" 'quail-use-package
  "$(0O:(BB" "$(0&d'GTT&,!JO:X5>KHA!K(B"
  "quail/Punct-b5")
-(register-input-method
- "chinese-py" "Chinese-GB" 'quail-use-package
- "$AF4(BG" "$A::WVJdHk!KF4Rt!K# (B"
- "quail/PY")
 (register-input-method
  "chinese-py-b5" "Chinese-BIG5" 'quail-use-package
  "$(03<(BB" "$(0&d'GTT&,!J3<5x!K(B"
@@ -62,38 +86,22 @@
  "chinese-ecdict" "Chinese-BIG5" 'quail-use-package
  "$(05CKH(B" "$(0&d'GTT&,!J5CKH[0.)!K(B"
  "quail/ECDICT")
-(register-input-method
- "chinese-ctlaub" "Chinese-BIG5" 'quail-use-package
- "$(0N,Gn(B" "$(0KH)tTT&,!(N,Tg>A*#Gn5x!((B"
- "quail/CTLauB")
-(register-input-method
- "chinese-ctlau" "Chinese-GB" 'quail-use-package
- "$AAuTA(B" "$A::WVJdHk!KAuN}OiJ=TARt!K(B"
- "quail/CTLau")
 (register-input-method
  "chinese-ccdospy" "Chinese-GB" 'quail-use-package
- "$AKuF4(B" "$A::WVJdHk!KKuP4F4Rt!K# (B"
+ "$AKuF4(B" "$A::WVJdHk!KKuP4F4Rt!K(B"
  "quail/CCDOSPY")
 (register-input-method
  "chinese-array30" "Chinese-BIG5" 'quail-use-package
- "$(0#R#O(B" "$(0&d'G!J*h)E#R#O!K(B "
+ "$(0#R#O(B" "$(0&d'G!J*h)E#R#O!K(B"
  "quail/ARRAY30")
 (register-input-method
  "chinese-4corner" "Chinese-BIG5" 'quail-use-package
- "$(0(?-F(B" "$(0(?-FHAP#(B:: "
+ "$(0(?-F(B" "$(0(?-FHAP#(B::"
  "quail/4Corner")
 (register-input-method
  "vietnamese-viqr" "Vietnamese" 'quail-use-package
  "VQ" "Vietnamese input method with VIQR mnemonic system"
  "quail/viqr")
-(register-input-method
- "chinese-cns-tsangchi" "Chinese-CNS" 'quail-use-package
- "$(GT?(BC" "$(GDcEFrSD+!JT?on!K(BCNS"
- "quail/tsang-cns")
-(register-input-method
- "chinese-b5-tsangchi" "Chinese-BIG5" 'quail-use-package
- "$(06A(BB" "$(0&d'GTT&,!J6AQo!K(BBIG5"
- "quail/tsang-b5")
 (register-input-method
  "tibetan-wylie" "Tibetan" 'quail-use-package
  "TIBw" "Tibetan character input by Extended Wylie key assignment."
@@ -130,14 +138,6 @@
  "slovak-prog-3" "Slovak" 'quail-use-package
  "SK" "Slovak (non-standard) keyboard for programmers #3."
  "quail/slovak")
-(register-input-method
- "chinese-cns-quick" "Chinese-CNS" 'quail-use-package
- "$(Gv|(BC" "$(GDcEFrSD+!Jv|Mx!K(BCNS"
- "quail/quick-cns")
-(register-input-method
- "chinese-b5-quick" "Chinese-BIG5" 'quail-use-package
- "$(0X|(BB" "$(0&d'GTT&,!JX|/y!K(BBIG5"
- "quail/quick-b5")
 (register-input-method
  "chinese-py-punct-b5" "Chinese-BIG5" 'quail-use-package
  "$AF47{(B" "$(0&d'GTT&,!J3<5x!K(B and `v' for $(0O:X5>KHATT&,(B"
@@ -146,6 +146,10 @@
  "chinese-py-punct" "Chinese-GB" 'quail-use-package
  "$AF47{(B" "$A::WVJdHk(B $AF4Rt7=08(B and `v' for $A1j5c7{:EJdHk(B"
  "quail/py-punct")
+(register-input-method
+ "chinese-tonepy-punct" "Chinese-GB" 'quail-use-package
+ "$AF47{(B" "$A::WVJdHk(B $A4x5wF4Rt7=08(B and `v' for $A1j5c7{:EJdHk(B"
+ "quail/py-punct")
 (register-input-method
  "lao-lrt" "Lao" 'quail-use-package
  "(1E(BR" "Lao input method using LRT (Lao Roman Transcription)."
@@ -159,7 +163,7 @@
  "CA>" "Catalan and Spanish input method with prefix modifiers"
  "quail/latin-pre")
 (register-input-method
- "esperanto-prefix" "Latin-1" 'quail-use-package
+ "esperanto-prefix" "Latin-3" 'quail-use-package
  "EO>" "Esperanto input method with prefix modifiers"
  "quail/latin-pre")
 (register-input-method
@@ -198,6 +202,18 @@
  "latin-3-prefix" "Latin-3" 'quail-use-package
  "3>" "Latin-3 characters input method with prefix modifiers"
  "quail/latin-pre")
+(register-input-method
+ "polish-slash" "Polish" 'quail-use-package
+ "PL>" "Polish diacritics in Latin-2 encoding are input as `/[acelnosxzACELNOSXZ]'."
+ "quail/latin-pre")
+(register-input-method
+ "latin-9-prefix" "Latin-9" 'quail-use-package
+ "0>" "Latin-9 characters input method with prefix modifiers"
+ "quail/latin-pre")
+(register-input-method
+ "latin-8-prefix" "Latin-8" 'quail-use-package
+ "8>" "Latin-8 characters input method with prefix modifiers"
+ "quail/latin-pre")
 (register-input-method
  "latin-1-postfix" "Latin-1" 'quail-use-package
  "1<" "Latin-1 character input method with postfix modifiers"
@@ -299,8 +315,8 @@
  "SV@" "Swedish (Svenska) input method simulating SUN Swedish/Finnish keyboard"
  "quail/latin-post")
 (register-input-method
- "finish-keyboard" "Latin-1" 'quail-use-package
- "FI@" "Finish input method simulating SUN Finnish/Swedish keyboard"
+ "finnish-keyboard" "Latin-1" 'quail-use-package
+ "FI@" "Finnish input method simulating SUN Finnish/Swedish keyboard"
  "quail/latin-post")
 (register-input-method
  "german" "Latin-1" 'quail-use-package
@@ -318,6 +334,10 @@
  "english-dvorak" "English" 'quail-use-package
  "DV@" "English (ASCII) input method simulating Dvorak keyboard"
  "quail/latin-post")
+(register-input-method
+ "TeX" "UTF-8" 'quail-use-package
+ "\\" "LaTeX-like input method for many characters."
+ "quail/latin-ltx")
 (register-input-method
  "latin-1-alt-postfix" "Latin-1" 'quail-use-package
  "1<" "Latin-1 character input method with postfix modifiers"
@@ -384,11 +404,11 @@
  "quail/latin-alt")
 (register-input-method
  "turkish-latin-3-alt-postfix" "Latin-3" 'quail-use-package
- "TR3<<" "Turkish (T,C|(Brk,Cg(Be) input method with postfix modifiers"
+ "TR3<<" "Turkish (T,C|(Brk,Cg(Be) input method with postfix modifiers."
  "quail/latin-alt")
 (register-input-method
  "turkish-alt-postfix" "Latin-5" 'quail-use-package
- "TR,M+(B" "Turkish (T,M|(Brk,Mg(Be) input method with postfix modifiers"
+ "TR,M+(B" "Turkish (T,M|(Brk,Mg(Be) input method with postfix modifiers."
  "quail/latin-alt")
 (register-input-method
  "lao" "Lao" 'quail-use-package
@@ -396,27 +416,27 @@
  "quail/lao")
 (register-input-method
  "japanese" "Japanese" 'quail-use-package
- "A$B$"(B" "Romaji -> Hiragana -> Kanji&Kana"
+ "A$B$"(B" "Japanese input method by Roman transliteration and Kana-Kanji conversion."
  "quail/japanese")
 (register-input-method
  "japanese-ascii" "Japanese" 'quail-use-package
- "Aa" "Temporary ASCII input mode while using Quail package `japanese'"
+ "Aa" "Temporary ASCII input mode used within the input method `japanese'."
  "quail/japanese")
 (register-input-method
  "japanese-zenkaku" "Japanese" 'quail-use-package
- "$B#A(B" "Japanese zenkaku alpha numeric character input method"
+ "$B#A(B" "Japanese zenkaku alpha numeric character input method."
  "quail/japanese")
 (register-input-method
  "japanese-hankaku-kana" "Japanese" 'quail-use-package
- "(I1(B" "Japanese hankaku katakana input method by Roman transliteration"
+ "(I1(B" "Japanese hankaku katakana input method by Roman transliteration."
  "quail/japanese")
 (register-input-method
  "japanese-hiragana" "Japanese" 'quail-use-package
- "$B$"(B" "Japanese hiragana input method by Roman transliteration"
+ "$B$"(B" "Japanese hiragana input method by Roman transliteration."
  "quail/japanese")
 (register-input-method
  "japanese-katakana" "Japanese" 'quail-use-package
- "$B%"(B" "Japanese katakana input method by Roman transliteration"
+ "$B%"(B" "Japanese katakana input method by Roman transliteration."
  "quail/japanese")
 (register-input-method
  "ipa" "IPA" 'quail-use-package
@@ -450,13 +470,25 @@
  "greek-jis" "Greek" 'quail-use-package
  "$B&8(B" "$B&%&K&K&G&M&I&J&A(B: Greek keyboard layout (JIS X0208.1983)"
  "quail/greek")
+(register-input-method
+ "greek-mizuochi" "Greek" 'quail-use-package
+ "CG" ""
+ "quail/greek")
+(register-input-method
+ "greek-babel" "Greek" 'quail-use-package
+ "BG" "The TeX Babel input method for Classical Greek using mule-unicode-0100-24ff."
+ "quail/greek")
+(register-input-method
+ "greek-ibycus4" "Greek" 'quail-use-package
+ "IB" "The Ibycus4 input method for Classical Greek using mule-unicode-0100-24ff."
+ "quail/greek")
 (register-input-method
  "greek" "Greek" 'quail-use-package
  ",FY(B" ",FEkkgmij\(B: Greek keyboard layout (ISO 8859-7)"
  "quail/greek")
 (register-input-method
  "ethiopic" "Ethiopic" 'quail-use-package
- (quote ("$(3$Q#U!.(B " (ethio-prefer-ascii-space "_" "$(3$h(B") (ethio-prefer-ascii-punctuation "." "$(3$i(B"))) "  QUAIL PACKAGE FOR ETHIOPIC (TIGRIGNA AND AMHARIC)"
+ (quote ("$(3$Q#U!.(B " (ethio-prefer-ascii-space "_" "$(3$h(B") (ethio-prefer-ascii-punctuation "." "$(3$i(B"))) "  Quail package for Ethiopic (Tigrigna and Amharic)"
  "quail/ethiopic")
 (register-input-method
  "devanagari-keyboard-a" "Devanagari" 'quail-use-package
